@@ -23,7 +23,7 @@
 // Configuration LDAP Saisie :
 $GLOBALS['LSconfig'] = array(
   'NetLDAP2' => '/usr/share/php/Net/LDAP2.php',
-  'Smarty' => '/usr/share/php/smarty/libs/Smarty.class.php',
+  'Smarty' => '/usr/share/php/smarty3/Smarty.class.php',
   'lang' => 'fr_FR',
   'encoding' => 'UTF8',
   'cacheLSprofiles' => true,
@@ -179,7 +179,7 @@ $GLOBALS['LSconfig'] = array(
 define('LS_THEME','default');
 define('LS_TEMPLATES_DIR', 'templates');
 define('LS_IMAGES_DIR', 'images');
-define('LS_CSS_DIR', 'css/'.LS_THEME);
+define('LS_CSS_DIR', 'css');
 
 //Debug
 define('LSdebug',false);
@@ -203,4 +203,5 @@ $GLOBALS['defaultJSscipts']=array(
   'LSinfosBox.js'
 );
 
-?>
+// CSS
+$GLOBALS['defaultCSSfiles']=array();
