@@ -1679,7 +1679,7 @@ class LSsession {
           } // fin foreach($profileInfos)
         } // fin is_array($profileInfos)
       } // fin foreach LSprofiles
-      LSdebug(self :: $LSprofiles);
+      LSdebug("LSprofiles : ".print_r(self :: $LSprofiles,1));
       return true;
     }
     else {
@@ -1782,7 +1782,8 @@ class LSsession {
           $LSaddonsViewsAccess[]=array (
             'LSaddon' => $addon,
             'id' => $viewId,
-            'label' => $viewConf['label']
+            'label' => $viewConf['label'],
+            'showInMenu' => $viewConf['showInMenu']
           );
         }
       }
@@ -1795,9 +1796,9 @@ class LSsession {
   /**
    * Dit si l'utilisateur est du profil pour le DN spécifié
    *
-   * @param[in] string $profile de l'objet
    * @param[in] string $dn DN de l'objet
-   * 
+   * @param[in] string $profile Profil
+   *
    * @retval boolean True si l'utilisateur est du profil sur l'objet, false sinon.
    */
   public static function isLSprofile($dn,$profile) {
@@ -1813,6 +1814,22 @@ class LSsession {
     }
     return;
   }
+
+  /**
+   * Dit si l'utilisateur est d'au moins un des profils pour le DN spécifié
+   *
+   * @param[in] string $dn DN de l'objet
+   * @param[in] string $profiles Profils
+   *
+   * @retval boolean True si l'utilisateur est d'au moins un profil sur l'objet, false sinon.
+   */
+  public static function isLSprofiles($dn,$profiles) {
+    foreach ($profiles as $profile) {
+      if (self :: isLSprofile($dn,$profile))
+        return true;
+    }
+    return false;
+  }
   
   /**
    * Retourne qui est l'utilisateur par rapport Ã  l'object
@@ -2501,9 +2518,11 @@ class LSsession {
    * @param[in] $allowedLSprofiles array|null Array listing allowed profiles.
    *                                          If null, no access control will
    *                                          be done for this view.
+   * @param[in] $showInMenu boolean Show (or not) this view in menu
+   *
    * @retval bool True is the view have been registred, false otherwise
    **/
-  public static function registerLSaddonView($LSaddon,$viewId,$label,$viewFunction,$allowedLSprofiles=null) {
+  public static function registerLSaddonView($LSaddon,$viewId,$label,$viewFunction,$allowedLSprofiles=null,$showInMenu=True) {
     if (function_exists($viewFunction)) {
       $func = new ReflectionFunction($viewFunction);
       if (basename($func->getFileName())=="LSaddons.$LSaddon.php") {
@@ -2511,7 +2530,8 @@ class LSsession {
           'LSaddon' => $LSaddon,
           'label' => $label,
           'function' => $viewFunction,
-          'allowedLSprofiles' => $allowedLSprofiles
+          'allowedLSprofiles' => $allowedLSprofiles,
+          'showInMenu' => (bool)$showInMenu
         );
         return True;
       }
